@@ -1,5 +1,5 @@
 /*************************************************************************************
- *  Copyright (C) 2007-2008 by Aleix Pol <aleixpol@gmail.com>                        *
+ *  Copyright (C) 2007-2008 by Aleix Pol <aleixpol@kde.org>                          *
  *                                                                                   *
  *  This program is free software; you can redistribute it and/or                    *
  *  modify it under the terms of the GNU General Public License                      *
@@ -38,6 +38,8 @@
 #include "analitza.h"
 #include "functionsmodel.h"
 
+// #define DEBUG_GRAPH
+
 using namespace std;
 
 QColor const Graph2D::m_axeColor(100,100,255);
@@ -46,7 +48,7 @@ QColor const Graph2D::m_derivativeColor(90,90,160);
 
 Graph2D::Graph2D(FunctionsModel* fm, QWidget *parent) :
 	QWidget(parent), m_model(fm),
-	valid(false), mode(None), m_squares(true), m_keepRatio(true), resolucio(800),
+	valid(false), mode(None), m_squares(true), m_keepRatio(true),
 	m_framed(false), m_readonly(false), m_posText()
 {
 	this->setFocusPolicy(Qt::ClickFocus);
@@ -56,7 +58,7 @@ Graph2D::Graph2D(FunctionsModel* fm, QWidget *parent) :
 	this->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 	
 	setViewport(QRectF(QPointF(-12., 10.), QSizeF(24., -20.)));
-	defViewport = viewport;
+	defViewport = userViewport;
 	this->setAutoFillBackground(false);
 	
 	connect(m_model, SIGNAL(dataChanged( const QModelIndex&, const QModelIndex& )),
@@ -64,7 +66,7 @@ Graph2D::Graph2D(FunctionsModel* fm, QWidget *parent) :
 	connect(m_model, SIGNAL( rowsInserted ( const QModelIndex &, int, int ) ),
 		this, SLOT(addFuncs(const QModelIndex&, int, int)));
 	connect(m_model, SIGNAL( rowsRemoved ( const QModelIndex &, int, int ) ),
-			this, SLOT(removeFuncs(const QModelIndex&, int, int)));
+		this, SLOT(removeFuncs(const QModelIndex&, int, int)));
 }
 
 Graph2D::~Graph2D() {}
@@ -82,10 +84,13 @@ void Graph2D::drawAxes(QPainter *f, function::Axe a)
 	}
 	
 	//write coords
-	f->drawText(QPointF(3.+this->width()/2., 13.               ), QString::number(viewport.top()));
-	f->drawText(QPointF(3.+this->width()/2., this->height()-5. ), QString::number(viewport.bottom()));
+	QString rightBound=QString::number(viewport.right());
+	int width=f->fontMetrics().width(rightBound);
+	
+	f->drawText(QPointF(3.+this->width()/2., 13.                 ), QString::number(viewport.top()));
+	f->drawText(QPointF(3.+this->width()/2., this->height()-5.   ), QString::number(viewport.bottom()));
 	f->drawText(QPointF(8.                 , this->height()/2.-5.), QString::number(viewport.left()));
-	f->drawText(QPointF(this->width()-30.  , this->height()/2.-5.),QString::number(viewport.right()));
+	f->drawText(QPointF(this->width()-width, this->height()/2.-5.), rightBound);
 	//EO write coords
 }
 
@@ -99,8 +104,8 @@ void Graph2D::drawPolarAxes(QPainter *w)
 	zero= center.x()>0. && center.y()>0. && center.x()<width() && center.y()<height();
 	double thmin = zero ? 0. : fmin(floor(fmin(viewport.left(), viewport.bottom())), ceil(fmax(viewport.right(), viewport.top())));
 	double thmax = ceil(fmax(
-				sqrt(pow(viewport.topRight().x(), qreal(2)) + pow(viewport.topRight().y(), qreal(2))),
-				sqrt(pow(viewport.bottomLeft().x(), qreal(2))+ pow(viewport.bottomLeft().y(), qreal(2)))
+				sqrt(pow(viewport.topRight().x(), 2.) + pow(viewport.topRight().y(), 2.)),
+				sqrt(pow(viewport.bottomLeft().x(), 2.)+ pow(viewport.bottomLeft().y(), 2.))
 			    )
 			);
 		
@@ -185,7 +190,7 @@ void Graph2D::drawCartesianAxes(QPainter *finestra)
 	finestra->drawPie(rectY, startAngleY, spanAngle);
 }
 
-void Graph2D::pintafunc(QPaintDevice *qpd)
+void Graph2D::drawFunctions(QPaintDevice *qpd)
 {
 	QPalette p=qApp->palette();
 	QPen pfunc;
@@ -218,26 +223,39 @@ void Graph2D::pintafunc(QPaintDevice *qpd)
 		finestra.setPen(pfunc);
 		
 		const QVector<QPointF> &vect=it->points();
-		Q_ASSERT(!vect.isEmpty());
 		QList<int> jumps=it->jumps();
 		
 		unsigned int pointsCount = vect.count();
 		QPointF ultim(toWidget(vect[0]));
 		
 		int nextjump= jumps.isEmpty() ? -1 : jumps.takeFirst();
+#ifdef DEBUG_GRAPH
+		qDebug() << "---------" << jumps.count()+1;
+#endif
 		for(unsigned int j=0; j<pointsCount; j++) {
 			QPointF act=toWidget(vect.at(j));
 			
-// 			QLineF deriv=it->derivative(ultim);
-// 			qDebug() << "inf" << deriv.dy()/deriv.dx() << deriv;
-			
-			if(isinf(act.y()) && !isnan(act.y())) qDebug() << "toma ya";
+// 			qDebug() << "xxxxx" << act << ultim << isnan(act.y()) << isnan(ultim.y());
+			if(isinf(act.y()) && !isnan(act.y())) qDebug() << "toma ya" << act << ultim;
 			else if(isinf(act.y()) && isnan(act.y())) qDebug() << "joooooooooooo";
 			
-			if(!isnan(act.y()) && !isnan(ultim.y()) && nextjump!=int(j)) {
-				finestra.drawLine(ultim, act);
+			bool bothinf=(isinf(ultim.y()) && isinf(act.y())) || (isinf(ultim.x()) && isinf(act.x()));
+			if(!bothinf && !isnan(act.y()) && !isnan(ultim.y()) && nextjump!=int(j)) {
+				if(isinf(ultim.y())) {
+					if(act.y()<0) ultim.setY(0);
+					if(act.y()>0) ultim.setY(qpd->height());
+				}
+// 				
+				QPointF act2(act);
+				if(isinf(act2.y())) {
+					if(ultim.y()<0) act2.setY(0);
+					if(ultim.y()>0) act2.setY(qpd->height());
+				}
 				
-#if 0
+// 				qDebug() << "xxxxx" << act2 << ultim << isnan(act2.y()) << isnan(ultim.y());
+				finestra.drawLine(ultim, act2);
+				
+#ifdef DEBUG_GRAPH
 				QPen p(Qt::red);
 				p.setWidth(3);
 				finestra.setPen(p);
@@ -250,8 +268,9 @@ void Graph2D::pintafunc(QPaintDevice *qpd)
 						finestra.drawPoint(act);
 					nextjump=jumps.isEmpty() ? -1 : jumps.takeFirst();
 				} while(!jumps.isEmpty() && jumps.first()==nextjump+1);
-#if 0
-				qDebug() << "jumpiiiiiing" << vect.at(j);
+				
+#ifdef DEBUG_GRAPH
+				qDebug() << "jumpiiiiiing" << ultim << toWidget(vect.at(j));
 				QPen p(Qt::blue);
 				p.setWidth(2);
 				finestra.setPen(p);
@@ -259,7 +278,7 @@ void Graph2D::pintafunc(QPaintDevice *qpd)
 				finestra.setPen(pfunc);
 #endif
 			}
-
+			
 			ultim=act;
 		}
 	}
@@ -268,10 +287,10 @@ void Graph2D::pintafunc(QPaintDevice *qpd)
 	valid=true;
 }
 
-void Graph2D::paintEvent( QPaintEvent * ev )
+void Graph2D::paintEvent(QPaintEvent * )
 {
 	if(!valid)
-		pintafunc(&buffer);
+		drawFunctions(&buffer);
 	
 	QPainter finestra(this);
 	finestra.drawPixmap(0,0,width(),height(), buffer);
@@ -286,7 +305,7 @@ void Graph2D::paintEvent( QPaintEvent * ev )
 		//Draw derivative
 		ccursor.setColor(m_derivativeColor);
 		ccursor.setStyle(Qt::SolidLine);
-		QLineF sl=slope(fromWidget(ultim));
+		QLineF sl=slope(mark);
 		sl.translate(mark);
 		
 		finestra.setPen(ccursor);
@@ -333,18 +352,23 @@ void Graph2D::paintEvent( QPaintEvent * ev )
 // 	qDebug() << "xxx2 " << viewport;
 }
 
-void Graph2D::wheelEvent(QWheelEvent *e){
+void Graph2D::wheelEvent(QWheelEvent *e)
+{
 	int d = e->delta()>0 ? -1 : 1;
-	if(viewport.left()-d < 1 && viewport.top()+d > 1 && viewport.right()+d > 1 && viewport.bottom()-d < 1) {
+	
+	if(d>0 || (viewport.width()+d > 2 && viewport.height()+d < 2)) {
+		QPointF p = fromWidget(e->pos());
 		QRectF nv;
 		nv.setLeft(viewport.left() - d);
 		nv.setTop(viewport.top() + d);
 		nv.setRight(viewport.right() + d);
 		nv.setBottom(viewport.bottom() - d);
+		setViewport(nv, false);
 		
+		QPointF p2 = p-fromWidget(e->pos());
+		nv.translate(p2);		
 		setViewport(nv);
 	}
-	sendStatus(QString("(%1, %2)-(%3, %4)").arg(viewport.left()).arg(viewport.top()).arg(viewport.right()).arg(viewport.bottom()));
 }
 
 void Graph2D::mousePressEvent(QMouseEvent *e){
@@ -361,7 +385,8 @@ void Graph2D::mousePressEvent(QMouseEvent *e){
 	}
 }
 
-void Graph2D::mouseReleaseEvent(QMouseEvent *e){
+void Graph2D::mouseReleaseEvent(QMouseEvent *e)
+{
 	if(m_readonly)
 		this->setCursor(Qt::ArrowCursor);
 	else
@@ -369,12 +394,27 @@ void Graph2D::mouseReleaseEvent(QMouseEvent *e){
 	
 	if(!m_readonly && mode==Selection) {
 		QPointF pd = toViewport(e->pos())-toViewport(press);
-		const double mindist = fmin(fabs(pd.x()), fabs(pd.y())), rate=7.;
-		const double minrate = fmin(fabs(viewport.width()/rate), fabs(viewport.height()/rate));
 		
-		if(mindist >= minrate) //if selection is not very small
-			setViewport(QRectF(fromWidget(press), QSizeF(pd.x(), pd.y())));
-		else
+		QPoint pd2 = e->pos()-press;
+		QRect rr(press, QSize(pd2.x(), pd2.y()));
+		
+		if(rr.width()>20 && rr.height()>20) { //if selection is not very small
+			QRectF r(fromWidget(press), QSizeF(pd.x(), pd.y()));
+			
+			if(r.top()<r.bottom()) {
+				double aux = r.bottom();
+				r.setBottom(r.top());
+				r.setTop(aux);
+			}
+			
+			if(r.right()<r.left()) {
+				double aux = r.left();
+				r.setLeft(r.right());
+				r.setRight(aux);
+			}
+			
+			setViewport(r);
+		} else
 			sendStatus(i18n("Selected viewport too small"));
 	}
 	mode = None;
@@ -395,7 +435,7 @@ void Graph2D::mouseMoveEvent(QMouseEvent *e)
 	} else if(e->buttons()&Qt::LeftButton) {
 		last = e->pos();
 	} else if(e->buttons()==0)
-		sendStatus(QString("x=%1 y=%2").arg(mark.x(),3,'f',2).arg(mark.y(),3,'f',2));
+		sendStatus(QString("x=%1 y=%2").arg(mark.x(),3,'g',5).arg(mark.y(),3,'g',5));
 	
 	this->repaint();
 }
@@ -406,24 +446,16 @@ void Graph2D::keyPressEvent(QKeyEvent * e)
 	
 	switch(e->key()) {
 		case Qt::Key_Right:
-			userViewport.setLeft(viewport.left() +xstep);
-			userViewport.setRight(viewport.right() +xstep);
-			updateScale();
+			setViewport(userViewport.translated(xstep, 0));
 			break;
 		case Qt::Key_Left:
-			userViewport.setLeft(viewport.left() -xstep);
-			userViewport.setRight(viewport.right() -xstep);
-			updateScale();
+			setViewport(userViewport.translated(-xstep, 0));
 			break;
 		case Qt::Key_Down:
-			userViewport.setTop(viewport.top() -ystep);
-			userViewport.setBottom(viewport.bottom() -ystep);
-			updateScale();
+			setViewport(userViewport.translated(0, -ystep));
 			break;
 		case Qt::Key_Up:
-			userViewport.setTop(viewport.top() +ystep);
-			userViewport.setBottom(viewport.bottom() +ystep);
-			updateScale();
+			setViewport(userViewport.translated(0, ystep));
 			break;
 		case Qt::Key_Minus:
 			zoomOut();
@@ -434,7 +466,6 @@ void Graph2D::keyPressEvent(QKeyEvent * e)
 		default:
 			return;
 	}
-	forceRepaint();
 }
 
 QPointF Graph2D::calcImage(const QPointF& ndp)
@@ -463,7 +494,7 @@ QPointF Graph2D::toWidget(const QPointF& p) const
 	return QPointF((left + p.x()) * rang_x,  (top + p.y()) * rang_y);
 }
 
-QPointF Graph2D::fromWidget(const QPointF& p) const
+QPointF Graph2D::fromWidget(const QPoint& p) const
 {
 	double part_negativa_x = -viewport.left();
 	double part_negativa_y = -viewport.top();
@@ -475,40 +506,25 @@ QPointF Graph2D::toViewport(const QPoint &mv) const
 	return QPointF(mv.x()/rang_x, mv.y()/rang_y);
 }
 
-void Graph2D::setResolution(int res)
-{
-	resolucio = res;
-}
-
-void Graph2D::setViewport(const QRectF &vp)
+void Graph2D::setViewport(const QRectF& vp, bool repaint)
 {
 	userViewport = vp;
-	if(userViewport.top()<userViewport.bottom()) {
-		double aux = userViewport.bottom();
-		userViewport.setBottom(userViewport.top());
-		userViewport.setTop(aux);
-	}
-	
-	if(userViewport.right()<userViewport.left()) {
-		double aux = userViewport .left();
-		userViewport.setLeft(userViewport .right());
-		userViewport.setRight(aux);
-	}
+	Q_ASSERT(userViewport.top()>userViewport.bottom());
+	Q_ASSERT(userViewport.right()>userViewport.left());
 	
 	sendStatus(QString("(%1, %2)-(%3, %4)")
 			.arg(viewport.left()).arg(viewport.top()).arg(viewport.right()).arg(viewport.bottom()));
-	updateScale();
+	updateScale(repaint);
+	
+	emit viewportChanged(userViewport);
 }
 
 void Graph2D::resizeEvent(QResizeEvent *)
 {
 	buffer=QPixmap(this->size());
 	updateScale();
-	repaint();
 }
 
-
-
 QRect Graph2D::toBiggerRect(const QRectF& ent)
 {
 	QRect ret;
@@ -529,8 +545,7 @@ bool Graph2D::toImage(const QString &path)
 		QSvgGenerator gen;
 		gen.setOutputDevice(&f);
 		gen.setSize(this->size());
-//		gen.setResolution(100);
-		pintafunc(&gen);
+		drawFunctions(&gen);
 		b=true;
 		forceRepaint();
 	} else if(!path.isEmpty() && path.endsWith(".png")) {
@@ -541,7 +556,7 @@ bool Graph2D::toImage(const QString &path)
 	return b;
 }
 
-void Graph2D::updateScale()
+void Graph2D::updateScale(bool repaint)
 {
 	viewport=userViewport;
 	rang_x= width()/viewport.width();
@@ -566,9 +581,11 @@ void Graph2D::updateScale()
 // 		Q_ASSERT(userViewport.center() == viewport.center());
 	}
 	
-	if(m_model->rowCount())
-		update(m_model->index(0,0), m_model->index(m_model->rowCount()-1,0));
-	forceRepaint();
+	if(repaint) {
+		if(m_model->rowCount())
+			update(m_model->index(0,0), m_model->index(m_model->rowCount()-1,0));
+		forceRepaint();
+	}
 }
 
 void Graph2D::zoomIn()
@@ -576,7 +593,6 @@ void Graph2D::zoomIn()
 	if(userViewport.height() < -3. && userViewport.width() > 3.){
 		setViewport(QRect(userViewport.left() +1., userViewport.top() -1.,
 					userViewport.width() -2., userViewport.height() +2.));
-		updateScale();
 	}
 }
 
@@ -586,7 +602,6 @@ void Graph2D::zoomOut()
 	//resolucio=(resolucio*viewport.width())/(viewport.width()+2.);
 	setViewport(QRect(userViewport.left() -1., userViewport.top() +1.,
 				userViewport.width() +2., userViewport.height() -2.));
-	updateScale();
 }
 
 void Graph2D::update(const QModelIndex & startIdx, const QModelIndex & endIdx)
@@ -595,7 +610,7 @@ void Graph2D::update(const QModelIndex & startIdx, const QModelIndex & endIdx)
 	int start=startIdx.row(), end=endIdx.row();
 	
 	for(int i=start; i<=end; i++) {
-		m_model->updatePoints(i, toBiggerRect(viewport), static_cast<int>(floor(resolucio)));
+		m_model->updatePoints(i, toBiggerRect(viewport));
 	}
 	valid=false;
 	repaint();
@@ -603,14 +618,21 @@ void Graph2D::update(const QModelIndex & startIdx, const QModelIndex & endIdx)
 
 void Graph2D::addFuncs(const QModelIndex & parent, int start, int end)
 {
+	Q_ASSERT(!parent.isValid());
+	
 	for(int i=start; i<=end; i++) {
-		m_model->updatePoints(i, toBiggerRect(viewport), static_cast<int>(floor(resolucio)));
+		m_model->updatePoints(i, toBiggerRect(viewport));
 	}
 	valid=false;
+	repaint();
 }
 
 void Graph2D::removeFuncs(const QModelIndex & parent, int start, int end)
 {
+	Q_UNUSED(parent)
+	Q_UNUSED(start)
+	Q_UNUSED(end)
+	
 	valid=false;
 	repaint();
 }
@@ -618,7 +640,7 @@ void Graph2D::removeFuncs(const QModelIndex & parent, int start, int end)
 void Graph2D::setKeepAspectRatio(bool ar)
 {
 	m_keepRatio=ar;
-	forceRepaint();
+	updateScale();
 }
 
 void Graph2D::setReadOnly(bool ro)
@@ -627,5 +649,14 @@ void Graph2D::setReadOnly(bool ro)
 	this->setCursor(ro ? Qt::ArrowCursor : Qt::CrossCursor);
 	setMouseTracking(!ro);
 }
+void Graph2D::setModel(FunctionsModel* f)
+{
+	m_model=f;
+}
+
+QRectF Graph2D::definedViewport() const
+{
+	return userViewport;
+}
 
 #include "graph2d.moc"
