@@ -31,10 +31,8 @@
 #include <QFile>
 #include <QLabel>
 #include <QImage>
-#include <QLayout>
 #include <QPushButton>
 #include <QStackedWidget>
-#include <QDebug>
 
 #include "element.h"
 #include "orbitswidget.h"
@@ -42,6 +40,7 @@
 #include "spectrumviewimpl.h"
 #include "kalziumutils.h"
 #include "kalziumtabletype.h"
+#include "prefs.h"
 
 DetailedInfoDlg::DetailedInfoDlg( int el , QWidget *parent )
     : KPageDialog( parent ), m_ktt( 0 )
@@ -242,6 +241,76 @@ QString DetailedInfoDlg::getHtml( DATATYPE type )
             html.append( "<tr><td><img src=\"structure.png\" alt=\"icon\"/></td><td>" );
             html.append( i18n( "Electronegativity: %1", KalziumUtils::prettyUnit( m_element, ChemicalDataObject::electronegativityPauling ) ) );
             html.append( "</td></tr>" );
+            break;
+        }
+        case EXTRA:
+        {
+            QString language;
+            QString link;
+
+            switch ( Prefs::language() )
+                    {
+                        case 0: //English
+                                language = i18n("English");
+                                link = "en";
+                                break;
+                        case 1: //German
+                                language = i18n("German");
+                                link = "de";
+                                break;
+                        case 2: //French
+                                language = i18n("French");
+                                link = "fr";
+                                break;
+                        case 3: //Italian
+                                language = i18n("Italian");
+                                link = "it";
+                                break;
+                        case 4: //Russian
+                                language = i18n("Russian");
+                                link = "ru";
+                                break;
+                        case 5: //Japanese
+                                language = i18n("Japanese");
+                                link = "ja";
+                                break;
+                        case 6: //Spanish
+                                language = i18n("Spanish");
+                                link = "es";
+                                break;
+                        case 7: //Polish
+                                language = i18n("Polish");
+                                link = "pl";
+                                break;
+                        case 8: //Portuguese
+                                language = i18n("Portuguese");
+                                link = "pt";
+                                break;
+                        case 9: //Dutch
+                                language = i18n("Dutch");
+                                link = "nl";
+                                break;
+                    }
+            //Wikipedia.org
+            html.append ( "<tr><td><img src=\"wiki.png\" alt=\"icon\"/></td><td>" );
+
+            html.append ( "<a href=\"http:\\\\");        // http://
+            html.append (link);                          // en.
+            html.append (".wikipedia.org\\");            // wikipedia.org
+            html.append ( m_element->dataAsString( ChemicalDataObject::name ) ); // /hydrogen
+            html.append ( "\"> Wikipedia ");
+            html.append (language);
+            html.append ( "</a></td></tr>" );
+
+            // Example from the comment "http://en.wikipedia.org/hydrogen"
+            //chemipedia.org
+            //html.append( "<tr><td><img src=\"chemi.png\" alt=\"icon\"/></td><td>" );
+
+            //html.append( "</td></tr>" );
+            //physics.nist.gov
+            //html.append( "<tr><td><img src=\"nist.png\" alt=\"icon\"/></td><td>" );
+
+            //html.append( "</td></tr>" );
         }
     }
 
@@ -381,6 +450,7 @@ void DetailedInfoDlg::createContent()
 	m_htmlpages["misc"] = addHTMLTab( i18n( "Miscellaneous" ), i18n( "Miscellaneous" ), "misc" );
 	m_htmlpages["isotopes"] = addHTMLTab( i18n( "Isotopes" ), i18n( "Isotopes" ), "isotopemap" );
 	m_htmlpages["new"] = addHTMLTab( i18n( "Data Overview" ), i18n( "Data Overview" ), "applications-science" );
+	m_htmlpages["extra"] = addHTMLTab( i18n( "Extra information" ), i18n( "Extra Information" ), "applications-internet" );
 
 	// spectrum widget tab
 	QWidget *m_pSpectrumTab = new QWidget();
@@ -435,6 +505,7 @@ void DetailedInfoDlg::reloadContent()
     fillHTMLTab( m_htmlpages["new"], getHtml( DATA ) );
     fillHTMLTab( m_htmlpages["misc"], getHtml( MISC ) );
     fillHTMLTab( m_htmlpages["isotopes"], getHtml( ISOTOPES ) );
+    fillHTMLTab( m_htmlpages["extra"], getHtml( EXTRA ) );
 
     Spectrum * spec =  KalziumDataObject::instance()->spectrum( m_elementNumber );
 
