@@ -6,6 +6,7 @@
 // the source code.
 //
 // Copyright 2007      Murad Tagirov <tmurad@gmail.com>
+// Copyright 2009      Patrick Spendrin <ps_ml@gmx.de>
 //
 
 
@@ -20,13 +21,15 @@ namespace Marble
 class AbstractFileViewItem
 {
   public:
+    enum Roles {
+        FilePointerRole = Qt::UserRole + 1
+    };
     virtual ~AbstractFileViewItem() {};
 
     virtual void saveFile() = 0;
-    virtual void closeFile() = 0;
-    virtual QVariant data() const = 0;
     virtual bool isShown() const = 0;
     virtual void setShown( bool value ) = 0;
+    virtual QString name() const = 0;
 };
 
 }
