@@ -5,7 +5,7 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2008-2009    Torsten Rahn <tackat@kde.org>"
+// Copyright 2008-2009    Torsten Rahn <tackat@kde.org>
 //
 
 //
@@ -13,8 +13,8 @@
 //
 
 
-#ifndef __MARBLE__ABSTRACTTILE_P_H
-#define __MARBLE__ABSTRACTTILE_P_H
+#ifndef MARBLE_ABSTRACTTILE_P_H
+#define MARBLE_ABSTRACTTILE_P_H
 
 #include "TileId.h"
 
@@ -23,7 +23,8 @@ namespace Marble
 {
 
 
-class AbstractTilePrivate {
+class AbstractTilePrivate
+{
  public:
     AbstractTilePrivate( const TileId& id );
     virtual ~AbstractTilePrivate();
@@ -39,4 +40,4 @@ class AbstractTilePrivate {
 
 }
 
-#endif // __MARBLE__ABSTRACTTILE_P_H
+#endif // MARBLE_ABSTRACTTILE_P_H
