@@ -5,22 +5,18 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
-// Copyright 2008      Jens-Michael Hoffmann <jensmh@gmx.de>
-// Copyright 2008      Patrick Spendrin <ps_ml@gmx.de>
+// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
+// Copyright 2008,2009 Jens-Michael Hoffmann <jensmh@gmx.de>
+// Copyright 2008-2009      Patrick Spendrin <ps_ml@gmx.de>
 //
 
 #include "MarbleModel.h"
 
 #include <cmath>
 
-#if QT_VERSION < 0x040400
-# include <qatomic.h>
-#else
-# include <QtCore/QAtomicInt>
-#endif
-#include <QtCore/QDebug>
+#include <QtCore/QAtomicInt>
+#include <QtCore/QPointer>
 #include <QtCore/QTime>
 #include <QtCore/QTimer>
 #include <QtCore/QAbstractItemModel>
@@ -28,12 +24,15 @@
 #include <QtGui/QSortFilterProxyModel>
 
 #include "global.h"
+#include "MarbleDebug.h"
 #include "gps/GpsLayer.h"
 
 #include "GeoSceneDocument.h"
+#include "GeoSceneFilter.h"
 #include "GeoSceneHead.h"
 #include "GeoSceneLayer.h"
 #include "GeoSceneMap.h"
+#include "GeoScenePalette.h"
 #include "GeoSceneTexture.h"
 #include "GeoSceneVector.h"
 #include "GeoSceneXmlDataSource.h"
@@ -42,15 +41,15 @@
 #include "GeoDataStyle.h"
 
 #include "DgmlAuxillaryDictionary.h"
-
+#include "ExtDateTime.h"
+#include "FileStoragePolicy.h"
 #include "GeoPainter.h"
 #include "FileViewModel.h"
 #include "SphericalScanlineTextureMapper.h"
 #include "EquirectScanlineTextureMapper.h"
 #include "MercatorScanlineTextureMapper.h"
-#include "GeoPolygon.h"
 #include "gps/GpxFileModel.h"
-#include "GridMap.h"
+#include "gps/GpxFile.h"
 #include "HttpDownloadManager.h"
 #include "KmlFileViewItem.h"
 #include "LayerManager.h"
@@ -59,9 +58,11 @@
 #include "MarblePlacemarkModel.h"
 #include "MarbleGeometryModel.h"
 #include "MergedLayerDecorator.h"
-#include "PlaceMarkManager.h"
-#include "PlaceMarkLayout.h"
-#include "PlaceMarkPainter.h"
+#include "FileManager.h"
+#include "PlacemarkManager.h"
+#include "PlacemarkLayout.h"
+#include "PlacemarkPainter.h"
+#include "Planet.h"
 #include "StoragePolicy.h"
 #include "SunLocator.h"
 #include "TextureColorizer.h"
@@ -69,6 +70,7 @@
 #include "TileCreator.h"
 #include "TileCreatorDialog.h"
 #include "TileLoader.h"
+#include "TileLoaderHelper.h"
 #include "VectorComposer.h"
 #include "ViewParams.h"
 #include "ViewportParams.h"
@@ -76,10 +78,6 @@
 namespace Marble
 {
 
-#if QT_VERSION < 0x040400
-    typedef QAtomic QAtomicInt;
-#endif
-
 class MarbleModelPrivate
 {
  public:
@@ -87,14 +85,21 @@ class MarbleModelPrivate
         : m_parent( parent ),
           m_dataFacade( 0 ),
           m_mapTheme( 0 ),
-          m_layerManager( 0 )
+          m_layerManager( 0 ),
+          m_downloadManager( new HttpDownloadManager( new FileStoragePolicy(
+                                                                   MarbleDirs::localPath() ))),
+          m_fileManager( 0 ),
+          m_placemarkmanager( 0 )
     {
     }
 
-    void  resize( int width, int height );
-    void  notifyModelChanged();
-    void  geoDataDocumentLoaded( GeoDataDocument& document );
-    void geoDataDocumentAdded( GeoDataDocument* document );
+    ~MarbleModelPrivate()
+    {
+        delete m_downloadManager;
+    }
+
+    void resize( int width, int height );
+    void notifyModelChanged();
 
     static QAtomicInt       refCounter;
     MarbleModel             *m_parent;
@@ -111,13 +116,12 @@ class MarbleModelPrivate
     AbstractScanlineTextureMapper   *m_texmapper;
 
     static VectorComposer   *m_veccomposer; // FIXME: Make not a pointer.
-    GridMap                 *m_gridmap;
 
     // Places on the map
-    PlaceMarkManager        *m_placemarkmanager;
-    MarblePlacemarkModel    *m_placemarkmodel;
-    PlaceMarkLayout         *m_placeMarkLayout;
-    MarbleGeometryModel     *m_geometrymodel;
+    FileManager             *m_fileManager;
+    PlacemarkManager        *m_placemarkmanager;
+    PlacemarkLayout         *m_placemarkLayout;
+    QSortFilterProxyModel   *m_popSortModel;
 
     // Misc stuff.
     ExtDateTime             *m_dateTime;
@@ -133,7 +137,8 @@ class MarbleModelPrivate
 
     QTimer                  *m_timer;
 
-    FileViewModel           *m_fileviewmodel;
+
+    Planet                  *m_planet;
 };
 
 VectorComposer      *MarbleModelPrivate::m_veccomposer = 0;
@@ -144,73 +149,76 @@ MarbleModel::MarbleModel( QObject *parent )
     : QObject( parent ),
       d( new MarbleModelPrivate( this ) )
 {
+    QTime t;
+    t.start();
     MarbleModelPrivate::refCounter.ref();
+    connect( this, SIGNAL( downloadTile( QUrl, QString, QString )),
+             d->m_downloadManager, SLOT( addJob( QUrl, QString, QString )));
     d->m_dataFacade = new MarbleDataFacade( this );
+
+    d->m_tileLoader = new TileLoader( d->m_downloadManager, this );
+
+    d->m_texmapper = 0;
+    
+    d->m_fileManager = new FileManager();
+    d->m_fileManager->setDataFacade(d->m_dataFacade);
+
+    d->m_placemarkmanager = new PlacemarkManager();
+    d->m_placemarkmanager->setDataFacade(d->m_dataFacade);
+    d->m_placemarkmanager->setFileManager(d->m_fileManager);
+
+    d->m_popSortModel = new QSortFilterProxyModel( this );
+
+    d->m_popSortModel->setSourceModel( d->m_dataFacade->placemarkModel() );
+//    d->m_popSortModel->setSortLocaleAware( true );
+//    d->m_popSortModel->setDynamicSortFilter( true );
+    d->m_popSortModel->setSortRole( MarblePlacemarkModel::PopularityIndexRole );
+    d->m_popSortModel->sort( 0, Qt::DescendingOrder );
+    
+    d->m_placemarkselectionmodel = new QItemSelectionModel( d->m_popSortModel );
+
+    d->m_placemarkLayout = new PlacemarkLayout( this );
+    connect( d->m_placemarkselectionmodel,  SIGNAL( selectionChanged( QItemSelection,
+                                                                      QItemSelection) ),
+             d->m_placemarkLayout,          SLOT( requestStyleReset() ) );
+    connect( d->m_dataFacade->placemarkModel(),           SIGNAL( layoutChanged() ),
+             d->m_placemarkLayout,          SLOT( requestStyleReset() ) );
+
+    /*
+     * Create FileViewModel
+     */
+    connect( d->m_dataFacade->fileViewModel(), SIGNAL( modelChanged() ),
+             this,            SIGNAL( modelChanged() ) );
+
+    d->m_gpxFileModel = new GpxFileModel( this );
+    d->m_gpsLayer = new GpsLayer( d->m_gpxFileModel );
+
+    connect( d->m_dataFacade->fileViewModel(), SIGNAL(layoutChanged()),
+             d->m_gpsLayer, SLOT(clearModel() ) );
+
     d->m_layerManager = new LayerManager( d->m_dataFacade, this );
 
     // FIXME: more on the spot update names and API
     connect ( d->m_layerManager,      SIGNAL( floatItemsChanged() ),
               this,                   SIGNAL( modelChanged() ) );
 
+    connect ( d->m_layerManager, SIGNAL( pluginSettingsChanged() ),
+              this,              SIGNAL( pluginSettingsChanged() ) );
+    connect ( d->m_layerManager, SIGNAL( repaintNeeded( QRegion ) ),
+              this,              SIGNAL( repaintNeeded( QRegion ) ) );
+    connect ( d->m_layerManager, SIGNAL( renderPluginInitialized( RenderPlugin * ) ),
+              this,              SIGNAL( renderPluginInitialized( RenderPlugin * ) ) );
+
     d->m_timer = new QTimer( this );
     d->m_timer->start( 200 );
 
     connect( d->m_timer, SIGNAL( timeout() ),
              this,       SIGNAL( timeout() ) );
 
-    d->m_downloadManager = 0;
-
-    d->m_tileLoader = new TileLoader( d->m_downloadManager, this );
-
-    d->m_texmapper = 0;
-    d->m_gridmap      = new GridMap( this );
-    
-    if( MarbleModelPrivate::refCounter == 1 ) {
-        d->m_veccomposer = new VectorComposer();
-        d->m_texcolorizer = 0;
-        /* d->m_texcolorizer is not initialized here since it takes a long time
-           to create the palette and it might not even be used. Instead it's created
-           in setMapTheme if the theme being loaded does need it. If the theme
-           doesn't need it, it's left as is. */
-    }
-
-    d->m_placemarkmanager   = new PlaceMarkManager();
-
-    connect( d->m_placemarkmanager, SIGNAL( geoDataDocumentLoaded( GeoDataDocument& ) ),
-             this,                  SLOT( geoDataDocumentLoaded( GeoDataDocument& ) ) );
-    connect( d->m_placemarkmanager, SIGNAL( geoDataDocumentAdded( GeoDataDocument* ) ),
-             this,                  SLOT( geoDataDocumentAdded( GeoDataDocument* ) ) );
-
-    d->m_placemarkmodel = new MarblePlacemarkModel( d->m_placemarkmanager, this );
-    d->m_placemarkselectionmodel = new QItemSelectionModel( d->m_placemarkmodel );
-    d->m_geometrymodel = new MarbleGeometryModel();
-    d->m_placemarkmanager->setGeoModel( d->m_geometrymodel );
-
-    d->m_placeMarkLayout = new PlaceMarkLayout( this );
-    connect( d->m_placemarkmanager,         SIGNAL( finalize() ),
-             d->m_placeMarkLayout,          SLOT( requestStyleReset() ) );
-    connect( d->m_placemarkselectionmodel,  SIGNAL( selectionChanged( QItemSelection,
-                                                                      QItemSelection) ),
-             d->m_placeMarkLayout,          SLOT( requestStyleReset() ) );
-    connect( d->m_placemarkmodel,           SIGNAL( layoutChanged() ),
-             d->m_placeMarkLayout,          SLOT( requestStyleReset() ) );
-
-    d->m_gpxFileModel = new GpxFileModel( this );
-    d->m_gpsLayer = new GpsLayer( d->m_gpxFileModel );
-
-    connect( d->m_gpxFileModel, SIGNAL( updateRegion( BoundingBox& ) ),
-             this,              SIGNAL( regionChanged( BoundingBox& ) ) );
-
-    /*
-     * Create FileViewModel
-     */
-    d->m_fileviewmodel = new FileViewModel( this );
-
-    connect( d->m_fileviewmodel, SIGNAL( updateRegion( BoundingBox& ) ),
-             this,               SIGNAL( regionChanged( BoundingBox& ) ) );
-
     d->m_dateTime       = new ExtDateTime();
-    d->m_sunLocator     = new SunLocator( d->m_dateTime );
+    /* Assume we are dealing with the earth */
+    d->m_planet = new Planet( "earth" );
+    d->m_sunLocator     = new SunLocator( d->m_dateTime, d->m_planet );
     d->m_layerDecorator = new MergedLayerDecorator( d->m_sunLocator );
 
     connect(d->m_dateTime,   SIGNAL( timeChanged() ),
@@ -221,21 +229,19 @@ MarbleModel::MarbleModel( QObject *parent )
 
 MarbleModel::~MarbleModel()
 {
-//    qDebug() << "MarbleModel::~MarbleModel";
+//    mDebug() << "MarbleModel::~MarbleModel";
     
     delete d->m_texmapper;
 
     delete d->m_tileLoader; // disconnects from downloadManager in dtor
-    delete d->m_downloadManager;
 
     if( MarbleModelPrivate::refCounter == 1 ) {
         delete d->m_veccomposer;
         delete d->m_texcolorizer;
     }
-    delete d->m_gridmap;
-    delete d->m_geometrymodel;
-    delete d->m_placemarkmodel;
+    delete d->m_popSortModel;
     delete d->m_placemarkmanager;
+    delete d->m_fileManager;
     delete d->m_gpsLayer;
     delete d->m_mapTheme;
     delete d->m_timer;
@@ -244,9 +250,10 @@ MarbleModel::~MarbleModel()
     delete d->m_layerDecorator;
     delete d->m_sunLocator;
     delete d->m_dateTime;
+    delete d->m_planet;
     delete d;
     MarbleModelPrivate::refCounter.deref();
-    qDebug() << "Model deleted:" << this;
+    mDebug() << "Model deleted:" << this;
 }
 
 bool MarbleModel::showGps() const
@@ -299,22 +306,28 @@ void MarbleModel::setMapTheme( GeoSceneDocument* mapTheme,
     d->m_mapTheme = mapTheme;
 
     // Some output to show how to use this stuff ...
-    qDebug() << "DGML2 Name       : " << d->m_mapTheme->head()->name(); 
+    mDebug() << "DGML2 Name       : " << d->m_mapTheme->head()->name(); 
 /*
-    qDebug() << "DGML2 Description: " << d->m_mapTheme->head()->description(); 
+    mDebug() << "DGML2 Description: " << d->m_mapTheme->head()->description(); 
 
     if ( d->m_mapTheme->map()->hasTextureLayers() )
-        qDebug() << "Contains texture layers! ";
+        mDebug() << "Contains texture layers! ";
     else
-        qDebug() << "Does not contain any texture layers! ";
+        mDebug() << "Does not contain any texture layers! ";
 
-    qDebug() << "Number of SRTM textures: " << d->m_mapTheme->map()->layer("srtm")->datasets().count();
+    mDebug() << "Number of SRTM textures: " << d->m_mapTheme->map()->layer("srtm")->datasets().count();
 
     if ( d->m_mapTheme->map()->hasVectorLayers() )
-        qDebug() << "Contains vector layers! ";
+        mDebug() << "Contains vector layers! ";
     else
-        qDebug() << "Does not contain any vector layers! ";
+        mDebug() << "Does not contain any vector layers! ";
 */
+    //Don't change the planet unless we have to...
+    if( d->m_mapTheme->head()->target().toLower() != d->m_planet->id() ) {
+        mDebug() << "Changing Planet";
+        *(d->m_planet) = Planet( d->m_mapTheme->head()->target().toLower() );
+        sunLocator()->setPlanet(d->m_planet);
+    }
 
     if ( d->m_mapTheme->map()->hasTextureLayers() ) {
         // If the tiles aren't already there, put up a progress dialog
@@ -336,7 +349,7 @@ void MarbleModel::setMapTheme( GeoSceneDocument* mapTheme,
         if ( !TileLoader::baseTilesAvailable( layer )
             && !installMap.isEmpty() )
         {
-            qDebug() << "Base tiles not available. Creating Tiles ... \n"
+            mDebug() << "Base tiles not available. Creating Tiles ... \n"
                      << "SourceDir: " << sourceDir << "InstallMap:" << installMap;
             MarbleDirs::debug();
 
@@ -345,11 +358,12 @@ void MarbleModel::setMapTheme( GeoSceneDocument* mapTheme,
                                      installMap,
                                      (role == "dem") ? "true" : "false" );
 
-            TileCreatorDialog  tileCreatorDlg( tileCreator, 0 );
-            tileCreatorDlg.setSummary( d->m_mapTheme->head()->name(),
-                                       d->m_mapTheme->head()->description() );
-            tileCreatorDlg.exec();
+            QPointer<TileCreatorDialog> tileCreatorDlg = new TileCreatorDialog( tileCreator, 0 );
+            tileCreatorDlg->setSummary( d->m_mapTheme->head()->name(),
+                                        d->m_mapTheme->head()->description() );
+            tileCreatorDlg->exec();
             qDebug("Tile creation completed");
+            delete tileCreatorDlg;
         }
         d->m_tileLoader->setLayer( layer );
     }
@@ -360,9 +374,9 @@ void MarbleModel::setMapTheme( GeoSceneDocument* mapTheme,
     setupTextureMapper( currentProjection );
 
     // Set all the colors for the vector layers
-    if ( d->m_mapTheme->map()->hasVectorLayers() ) {
+    if ( d->m_mapTheme->map()->hasVectorLayers() && d->m_veccomposer ) {
         d->m_veccomposer->setOceanColor( d->m_mapTheme->map()->backgroundColor() );
-
+        
         // Just as with textures, this is a workaround for DGML2 to
         // emulate the old behaviour.
 
@@ -394,32 +408,26 @@ void MarbleModel::setMapTheme( GeoSceneDocument* mapTheme,
             }
         }
     }
-
-    d->m_geometrymodel->setGeoDataRoot( 0 );
-    QStringList loadedContainers = d->m_placemarkmanager->model()->containers();
+    d->m_dataFacade->geometryModel()->setGeoDataRoot( 0 );
+    QStringList loadedContainers = d->m_fileManager->containers();
     QStringList loadList;
-    QVector<GeoSceneLayer*>::const_iterator it = d->m_mapTheme->map()->layers().constBegin();
-    QVector<GeoSceneLayer*>::const_iterator end = d->m_mapTheme->map()->layers().constEnd();
+    const QVector<GeoSceneLayer*> & layers = d->m_mapTheme->map()->layers();
+    QVector<GeoSceneLayer*>::const_iterator it = layers.constBegin();
+    QVector<GeoSceneLayer*>::const_iterator end = layers.constEnd();
     for (; it != end; ++it) {
         GeoSceneLayer* layer = *it;
         if ( layer->backend() == dgml::dgmlValue_geodata && layer->datasets().count() > 0 ) {
             // look for documents
-            QVector<GeoSceneAbstractDataset*>::const_iterator itds = layer->datasets().constBegin();
-            QVector<GeoSceneAbstractDataset*>::const_iterator endds = layer->datasets().constEnd();
+            const QVector<GeoSceneAbstractDataset*> & datasets = layer->datasets();
+            QVector<GeoSceneAbstractDataset*>::const_iterator itds = datasets.constBegin();
+            QVector<GeoSceneAbstractDataset*>::const_iterator endds = datasets.constEnd();
             for (; itds != endds; ++itds) {
                 GeoSceneAbstractDataset* dataset = *itds;
                 if( dataset->fileFormat() == "KML" ) {
-#if QT_VERSION >= 0x040400
-                    loadedContainers.removeOne(
-reinterpret_cast<GeoSceneXmlDataSource*>(dataset)->filename() );
-#else
-                    int index = loadedContainers.indexOf(
-reinterpret_cast<GeoSceneXmlDataSource*>(dataset)->filename() );
-                    if (index != -1) {
-                        loadedContainers.removeAt(index);
-                    }
-#endif
-                    loadList << reinterpret_cast<GeoSceneXmlDataSource*>(dataset)->filename();          
+                    QString containername = reinterpret_cast<GeoSceneXmlDataSource*>(dataset)->filename();
+                    if( containername.endsWith(".kml") ) containername.remove(".kml");
+                    loadedContainers.removeOne( containername );
+                    loadList << containername;
                 }
             }
         }
@@ -427,17 +435,19 @@ reinterpret_cast<GeoSceneXmlDataSource*>(dataset)->filename() );
     // unload old standard Placemarks which are not part of the new map
     foreach(const QString& container, loadedContainers) {
         loadedContainers.pop_front();
-        d->m_placemarkmanager->model()->removePlaceMarks( container, loadedContainers.isEmpty() );
+        d->m_fileManager->removeFile( container );
     }
     // load new standard Placemarks
     foreach(const QString& container, loadList) {
         loadList.pop_front();
-        d->m_placemarkmanager->addPlaceMarkFile( container, loadList.isEmpty() );
+        d->m_fileManager->addFile( container );
     }
-    
+    d->notifyModelChanged();
+    d->m_placemarkLayout->requestStyleReset();
+
 
     // FIXME: Still needs to get fixed for the DGML2 refactoring
-//    d->m_placeMarkLayout->placeMarkPainter()->setDefaultLabelColor( d->m_maptheme->labelColor() );
+//    d->m_placemarkLayout->placemarkPainter()->setDefaultLabelColor( d->m_maptheme->labelColor() );
 
     if( !d->m_mapTheme->map()->filters().isEmpty() ) {
         GeoSceneFilter *filter= d->m_mapTheme->map()->filters().first();
@@ -469,9 +479,8 @@ reinterpret_cast<GeoSceneXmlDataSource*>(dataset)->filename() );
             }
         }
     }
-    qDebug() << "THEME CHANGED: ***" << mapTheme->head()->mapThemeId();
+    mDebug() << "THEME CHANGED: ***" << mapTheme->head()->mapThemeId();
     emit themeChanged( mapTheme->head()->mapThemeId() );
-    d->m_sunLocator->setBody(d->m_mapTheme->head()->target().toLower());
 
     d->m_layerManager->syncViewParamsAndPlugins( mapTheme );
 
@@ -500,6 +509,19 @@ void MarbleModel::setupTextureMapper( Projection projection )
              this,           SLOT( notifyModelChanged() ) );
 }
 
+void MarbleModel::setupVectorComposer()
+{
+    if( MarbleModelPrivate::refCounter == 1 ) {
+        d->m_veccomposer = new VectorComposer();
+        connect( d->m_veccomposer, SIGNAL( datasetLoaded() ), SIGNAL( modelChanged() ) );
+        d->m_texcolorizer = 0;
+        /* d->m_texcolorizer is not initialized here since it takes a long time
+           to create the palette and it might not even be used. Instead it's created
+           in setMapTheme if the theme being loaded does need it. If the theme
+           doesn't need it, it's left as is. */
+    }    
+}
+
 HttpDownloadManager* MarbleModel::downloadManager() const
 {
     return d->m_downloadManager;
@@ -522,7 +544,9 @@ void MarbleModelPrivate::resize( int width, int height )
     if ( m_mapTheme->map()->hasTextureLayers() ) {
         m_texmapper->resizeMap( width, height );
     }
-    m_veccomposer->resizeMap( width, height );
+    if ( m_veccomposer ) {
+        m_veccomposer->resizeMap( width, height );
+    }
 }
 
 
@@ -542,13 +566,18 @@ void MarbleModel::paintGlobe( GeoPainter *painter,
     GeoSceneLayer *layer = 
         static_cast<GeoSceneLayer*>( d->m_mapTheme->map()->layer( themeID ) );
 
+    QStringList renderPositions;
+    renderPositions << "STARS" << "BEHIND_TARGET";
+    d->m_layerManager->renderLayers( painter, viewParams, renderPositions );
+        
     if ( redrawBackground ) {
         if ( d->m_mapTheme->map()->hasTextureLayers() ) {
 
             // Create the height map image a.k.a viewParams->m_canvasImage.
             d->m_texmapper->mapTexture( viewParams );
 
-            if ( !viewParams->showElevationModel()
+            if ( d->m_veccomposer
+                && !viewParams->showElevationModel()
                 && layer->role() == "dem"
                 && !d->m_mapTheme->map()->filters().isEmpty() ) {
 
@@ -562,7 +591,7 @@ void MarbleModel::paintGlobe( GeoPainter *painter,
                 if( filter->type() == "colorize" ) {
                     d->m_texcolorizer->colorize( viewParams );
                 }
-            } //else { qDebug() << "No filters to act on..."; }
+            } //else { mDebug() << "No filters to act on..."; }
         }
     }
 
@@ -585,59 +614,26 @@ void MarbleModel::paintGlobe( GeoPainter *painter,
 
 //    qDebug( "Painted in %ims", t.elapsed() );
 
+    renderPositions.clear();
+    renderPositions << "SURFACE";
+
     // Paint the vector layer.
-    if ( d->m_mapTheme->map()->hasVectorLayers() ) {
+    if ( d->m_veccomposer && d->m_mapTheme->map()->hasVectorLayers() ) {
 
         if ( !d->m_mapTheme->map()->hasTextureLayers() ) {
             d->m_veccomposer->paintBaseVectorMap( painter, viewParams );
         }
+
+        d->m_layerManager->renderLayers( painter, viewParams, renderPositions );
+
         // Add further Vectors
         d->m_veccomposer->paintVectorMap( painter, viewParams );
     }
-
-    // Paint the lon/lat grid around the earth.
-    bool showGrid;
-
-    viewParams->propertyValue( "coordinate-grid", showGrid );
-
-    if ( showGrid ) {
-        QPen  gridpen( QColor( 231, 231, 231, 255 ) );
-
-        // FIXME: Why would the createFoo() functions be exposed in
-        //        the class GridMap?  Shouldn't just a call to
-        //        paintGrid() or paintEquator be enough?  The internal
-        //        create...() functions should be private and not
-        //        exposed to the outside.
-
-        // Create and paint a grid
-        d->m_gridmap->createGrid( viewParams->viewport() );
-        d->m_gridmap->setPen( gridpen );
-
-        bool antialiased = false;
-
-        if (   viewParams->mapQuality() == Marble::High
-            || viewParams->mapQuality() == Marble::Print ) {
-                antialiased = true;
-        }
-
-        d->m_gridmap->paintGridMap( painter, antialiased );
-
-        // Create and paint the tropics and polar circles
-        d->m_gridmap->createTropics( viewParams->viewport() );
-        gridpen.setStyle( Qt::DotLine );
-        // gridpen.setWidthF( 1.5f );
-        d->m_gridmap->setPen( gridpen );
-        d->m_gridmap->paintGridMap( painter, antialiased );
-
-        // Create and paint Equator
-        d->m_gridmap->createEquator( viewParams->viewport() );
-        // gridpen.setWidthF( 2.0f );
-        d->m_gridmap->setPen( gridpen );
-        d->m_gridmap->paintGridMap( painter, antialiased );
+    else {
+        d->m_layerManager->renderLayers( painter, viewParams, renderPositions );        
     }
 
-    // Paint the GeoDataPlaceMark layer
-#ifndef KML_GSOC
+    // Paint the GeoDataPlacemark layer
     bool showPlaces, showCities, showTerrain, showOtherPlaces;
 
     viewParams->propertyValue( "places", showPlaces );
@@ -646,144 +642,104 @@ void MarbleModel::paintGlobe( GeoPainter *painter,
     viewParams->propertyValue( "otherplaces", showOtherPlaces );
 
     if ( showPlaces && ( showCities || showTerrain || showOtherPlaces )
-         && d->m_placemarkmodel->rowCount() > 0 )
+         && d->m_popSortModel->rowCount() > 0 )
     {
-        d->m_placeMarkLayout->paintPlaceFolder( painter, viewParams,
-                                                d->m_placemarkmodel,
+        d->m_placemarkLayout->paintPlaceFolder( painter, viewParams,
+                                                d->m_popSortModel,
                                                 d->m_placemarkselectionmodel );
     }
-#else
-    /*
-     * Iterate over our KMLFolders and show placemarks from each folderList
-     * This folder list also will be displayed in MarbleControlBox
-     * So user could enable/disable each folder
-     */
-    if ( viewParams->m_showPlaceMarks ) {
-        QTime t;
-        t.start ();
-
-        const QList < GeoDataFolder* >& folderList = d->m_placemarkmanager->getFolderList();
-
-        bool firstTime = true;
-
-        for ( QList<GeoDataFolder*>::const_iterator iterator = folderList.constBegin();
-            iterator != folderList.constEnd();
-            ++iterator )
-        {
-            GeoDataFolder& folder = *( *iterator );
-
-            /*
-             * Show only placemarks which are visible
-             */
-            if ( folder.isVisible() ) {
-
-                PlaceMarkContainer& container = folder.activePlaceMarkContainer( *viewParams );
-
-                d->m_placeMarkLayout->paintPlaceFolder( painter, viewParams,
-                                                        &container, firstTime );
-
-                firstTime = false;
-            }
-        }
-
-        qDebug("Paint kml folder list. Elapsed: %d", t.elapsed());
-    }
-#endif
 
     // Paint the Gps Layer
-    d->m_gpsLayer->setVisible( viewParams->showGps() );
+//    d->m_gpsLayer->setVisible( viewParams->showGps() );
     //FIXME:We might just send ViewParams instead of this bunch of parameters
     d->m_gpsLayer->paintLayer( painter,
                                viewParams->canvasImage()->size(),
-                               viewParams,
-                               viewParams->viewport()->boundingBox() );
-    d->m_layerManager->renderLayers( painter, viewParams );
+                               viewParams );
+
+    renderPositions.clear();
+    renderPositions << "HOVERS_ABOVE_SURFACE" << "ATMOSPHERE"
+                    << "ORBIT" << "ALWAYS_ON_TOP" << "FLOAT_ITEM" << "USER_TOOLS";
+                               
+    d->m_layerManager->renderLayers( painter, viewParams, renderPositions );
 }
 
 
-QAbstractItemModel *MarbleModel::placeMarkModel() const
+QAbstractItemModel *MarbleModel::placemarkModel() const
 {
-    return d->m_placemarkmodel;
+    return d->m_dataFacade->placemarkModel();
 }
 
-QItemSelectionModel *MarbleModel::placeMarkSelectionModel() const
+QItemSelectionModel *MarbleModel::placemarkSelectionModel() const
 {
     return d->m_placemarkselectionmodel;
 }
 
-QAbstractItemModel *MarbleModel::geometryModel() const
-{
-    return d->m_geometrymodel;
-}
-
-VectorComposer    *MarbleModel::vectorComposer()   const
+VectorComposer *MarbleModel::vectorComposer() const
 {
     return d->m_veccomposer;
 }
 
-TextureColorizer  *MarbleModel::textureColorizer() const
+TextureColorizer *MarbleModel::textureColorizer() const
 {
     return d->m_texcolorizer;
 }
 
-AbstractScanlineTextureMapper    *MarbleModel::textureMapper()    const
+AbstractScanlineTextureMapper *MarbleModel::textureMapper() const
 {
     return d->m_texmapper;
 }
 
-PlaceMarkLayout *MarbleModel::placeMarkLayout() const
+PlacemarkLayout *MarbleModel::placemarkLayout() const
 {
-    return d->m_placeMarkLayout;
+    return d->m_placemarkLayout;
 }
 
-GpsLayer *MarbleModel::gpsLayer()         const
+GpsLayer *MarbleModel::gpsLayer() const
 {
     return d->m_gpsLayer;
 }
 
-GpxFileModel *MarbleModel::gpxFileModel()   const
+GpxFileModel *MarbleModel::gpxFileModel() const
 {
     return d->m_gpxFileModel;
 }
 
 FileViewModel *MarbleModel::fileViewModel() const
 {
-    return d->m_fileviewmodel;
+    return d->m_dataFacade->fileViewModel();
 }
 
-void MarbleModel::addPlaceMarkFile( const QString& filename )
+void MarbleModel::openGpxFile( const QString& filename )
 {
-    d->m_placemarkmanager->loadKml( filename, false );
+    GpxFile* gpxFile = new GpxFile( filename );
+    d->m_fileManager->addFile( filename );
+    d->m_gpxFileModel->addFile( gpxFile );
+}
+
+void MarbleModel::addPlacemarkFile( const QString& filename )
+{
+    d->m_fileManager->addFile( filename );
 
     d->notifyModelChanged();
 }
 
-void MarbleModel::addPlaceMarkData( const QString& data, const QString& key )
+void MarbleModel::addPlacemarkData( const QString& data, const QString& key )
 {
-    QStringList loadedContainers = d->m_placemarkmanager->model()->containers();
-    if( loadedContainers.contains( key ) )
-    {
-        d->m_placemarkmanager->model()->removePlaceMarks( key, false );
-    }
-    d->m_placemarkmanager->loadKmlFromData( data, key, false );
+    d->m_fileManager->addData( key, data );
 
     d->notifyModelChanged();
 }
 
-void MarbleModel::removePlaceMarkKey( const QString& key )
+void MarbleModel::removePlacemarkKey( const QString& fileName )
 {
-    QStringList loadedContainers = d->m_placemarkmanager->model()->containers();
-    if( loadedContainers.contains( key ) )
-    {
-        d->m_placemarkmanager->model()->removePlaceMarks( key, false );
-    }
+    d->m_fileManager->removeFile( fileName );
 
     d->notifyModelChanged();
 }
 
-QVector<QPersistentModelIndex> MarbleModel::whichFeatureAt( const QPoint& curpos ) const
+QVector<QModelIndex> MarbleModel::whichFeatureAt( const QPoint& curpos ) const
 {
-    return d->m_placeMarkLayout->whichPlaceMarkAt( curpos );
+    return d->m_placemarkLayout->whichPlacemarkAt( curpos );
 }
 
 void MarbleModelPrivate::notifyModelChanged()
@@ -791,124 +747,26 @@ void MarbleModelPrivate::notifyModelChanged()
     emit m_parent->modelChanged();
 }
 
-void MarbleModelPrivate::geoDataDocumentLoaded( GeoDataDocument& document )
-{
-    AbstractFileViewItem* item = new KmlFileViewItem( *m_placemarkmanager,
-                                                      document );
-
-    m_fileviewmodel->append( item );
-}
-
-void MarbleModelPrivate::geoDataDocumentAdded( GeoDataDocument* document )
-{
-    AbstractFileViewItem* item = new KmlFileViewItem( *m_placemarkmanager,
-                                                      *document );
-
-    foreach(GeoDataPlacemark* placemark, document->placemarks())
-    {
-        QString styleUrl = placemark->styleUrl().remove('#');
-        placemark->setStyle( document->style( styleUrl ) );
-    };
-    m_fileviewmodel->append( item );
-    
-    m_geometrymodel->setGeoDataRoot( document );
-}
-
 void MarbleModel::update()
 {
-    qDebug() << "MarbleModel::update()";
+    mDebug() << "MarbleModel::update()";
     QTimer::singleShot( 0, d->m_tileLoader, SLOT( update() ) );
 }
 
-// FIXME: We'd like to have a targetBody ("planet") class which stores all attributes we need.
-
 qreal MarbleModel::planetRadius()   const
 {
-    if ( d->m_mapTheme ) {
-        QString target = d->m_mapTheme->head()->target().toLower();
-
-        // I'd like to be able to use strings in switch statements ... 
-
-        // Make sure to use the radius, not the diameter!
-
-        // planets
-               if ( target == "mercury" ) {
-            return  2440000.0;
-        } else if ( target == "venus" ) {
-            return  6051800.0;
-        } else if ( target == "earth" ) {
-            return  6378000.0;
-        } else if ( target == "mars" ) {
-            return  3397000.0;
-        } else if ( target == "jupiter" ) {
-            return  71492000.0;
-        } else if ( target == "saturn" ) {
-            return  60268000.0;
-        } else if ( target == "uranus" ) {
-            return  25559000.0;
-        } else if ( target == "neptune" ) {
-            return  24766000.0;
-
-        // dwarf planets ... (everybody likes pluto)
-        } else if ( target == "pluto" ) {
-            return  1151000.0;
-
-        // sun and moon
-        } else if ( target == "sun" ) {
-            return  695000000.0;
-        } else if ( target == "moon" ) {
-            return  1738000.0;
-        }
-    }
-
-    // Fallback to assuming that we deal with the earth
-    return 6378000.0;
+    return d->m_planet->radius();
 }
 
 QString MarbleModel::planetName()   const
 {
-    if ( d->m_mapTheme ) {
-        QString target = d->m_mapTheme->head()->target().toLower();
-
-        // planets
-               if ( target == "mercury" ) {
-            return  QString("Mercury");
-        } else if ( target == "venus" ) {
-            return  QString("Venus");
-        } else if ( target == "earth" ) {
-            return  QString("Earth");
-        } else if ( target == "mars" ) {
-            return  QString("Mars");
-        } else if ( target == "jupiter" ) {
-            return  QString("Jupiter");
-        } else if ( target == "saturn" ) {
-            return  QString("Saturn");
-        } else if ( target == "uranus" ) {
-            return  QString("Uranus");
-        } else if ( target == "neptune" ) {
-            return  QString("Neptune");
-
-        // dwarf planets ... (everybody likes pluto)
-        } else if ( target == "pluto" ) {
-            return  QString("Pluto");
-
-        // sun and moon
-        } else if ( target == "sun" ) {
-            return  QString("Sun");
-        } else if ( target == "moon" ) {
-            return  QString("Moon");
-        }
-    }
-
-    // Fallback to assuming that we deal with the earth
-    return QString("Earth");
+    return d->m_planet->name();
 }
 
-
 ExtDateTime* MarbleModel::dateTime() const
 {
-//    qDebug() << "In dateTime, model:" << this;
-//    qDebug() << d << ":" << d->m_dateTime;
+//    mDebug() << "In dateTime, model:" << this;
+//    mDebug() << d << ":" << d->m_dateTime;
     return d->m_dateTime;
 }
 
@@ -925,7 +783,7 @@ MergedLayerDecorator* MarbleModel::layerDecorator() const
 void MarbleModel::clearVolatileTileCache()
 {
     d->m_tileLoader->update();
-    qDebug() << "Cleared Volatile Cache!";
+    mDebug() << "Cleared Volatile Cache!";
 }
 
 quint64 MarbleModel::volatileTileCacheLimit() const
@@ -963,7 +821,7 @@ void MarbleModel::clearPersistentTileCache()
         if ( !TileLoader::baseTilesAvailable( layer )
             && !installMap.isEmpty() )
         {
-            qDebug() << "Base tiles not available. Creating Tiles ... \n"
+            mDebug() << "Base tiles not available. Creating Tiles ... \n"
                      << "SourceDir: " << sourceDir << "InstallMap:" << installMap;
             MarbleDirs::debug();
 
@@ -972,42 +830,92 @@ void MarbleModel::clearPersistentTileCache()
                                      installMap,
                                      (role == "dem") ? "true" : "false" );
 
-            TileCreatorDialog  tileCreatorDlg( tileCreator, 0 );
-            tileCreatorDlg.setSummary( d->m_mapTheme->head()->name(),
-                       d->m_mapTheme->head()->description() );
-            tileCreatorDlg.exec();
+            QPointer<TileCreatorDialog> tileCreatorDlg = new TileCreatorDialog( tileCreator, 0 );
+            tileCreatorDlg->setSummary( d->m_mapTheme->head()->name(),
+                                        d->m_mapTheme->head()->description() );
+            tileCreatorDlg->exec();
             qDebug("Tile creation completed");
+            delete tileCreatorDlg;
         }
     }
 }
 
-void MarbleModel::paintTile(TextureTile* tile, int x, int y, int level,
-                            GeoSceneTexture *textureLayer, bool requestTileUpdate)
+void MarbleModel::paintTile( TextureTile* tile, int x, int y, int level,
+                             GeoSceneTexture *textureLayer, bool requestTileUpdate )
 {
-//    qDebug() << "MarbleModel::paintTile: " << "x: " << x << "y:" << y << "level: " << level << "requestTileUpdate" << requestTileUpdate;
+//    mDebug() << "MarbleModel::paintTile: " << "x: " << x << "y:" << y << "level: " << level
+//             << "requestTileUpdate" << requestTileUpdate;
     
     if ( d->m_downloadManager != 0 ) {
         connect( d->m_layerDecorator, SIGNAL( downloadTile( QUrl, QString, QString ) ),
                  d->m_downloadManager, SLOT( addJob( QUrl, QString, QString ) ) );
     }
 
-    d->m_layerDecorator->setInfo(x, y, level, tile->id());
-    d->m_layerDecorator->setTile(tile->tile());
-        
-    d->m_layerDecorator->paint("maps/" + textureLayer->sourceDir(), mapTheme() );
-    tile->loadTile(requestTileUpdate);
+    d->m_layerDecorator->setInfo( x, y, level, tile->id() );
+    d->m_layerDecorator->setTile( tile->tile() );
+
+    d->m_layerDecorator->paint( "maps/" + textureLayer->sourceDir(), mapTheme() );
+    tile->initJumpTables( requestTileUpdate );
 }
 
-QList<MarbleRenderPlugin *> MarbleModel::renderPlugins() const
+QList<RenderPlugin *> MarbleModel::renderPlugins() const
 {
     return d->m_layerManager->renderPlugins();
 }
 
-QList<MarbleAbstractFloatItem *> MarbleModel::floatItems() const
+QList<AbstractFloatItem *> MarbleModel::floatItems() const
 {
     return d->m_layerManager->floatItems();
 }
 
+QList<AbstractDataPlugin *> MarbleModel::dataPlugins()  const
+{
+    return d->m_layerManager->dataPlugins();
+}
+
+QList<AbstractDataPluginItem *> MarbleModel::whichItemAt( const QPoint& curpos ) const
+{
+    return d->m_layerManager->whichItemAt( curpos );
+}
+
+Planet* MarbleModel::planet() const
+{
+    return d->m_planet;
+}
+
+int MarbleModel::tileZoomLevel() const
+{
+    if (!d->m_texmapper)
+        return -1;
+
+    return d->m_texmapper->tileZoomLevel();
+}
+
+void MarbleModel::reloadMap() const
+{
+    if ( !d->m_mapTheme->map()->hasTextureLayers() )
+        return;
+
+    const QString themeId = d->m_mapTheme->head()->theme();
+    GeoSceneLayer * const layer = static_cast<GeoSceneLayer*>( d->m_mapTheme->map()->
+                                                               layer( themeId ));
+    Q_ASSERT( layer );
+    GeoSceneTexture * const texture = static_cast<GeoSceneTexture*>( layer->groundDataset() );
+    Q_ASSERT( texture );
+
+    Q_ASSERT( d->m_tileLoader );
+    QList<TileId> displayed = d->m_tileLoader->tilesOnDisplay();
+    QList<TileId>::const_iterator pos = displayed.constBegin();
+    QList<TileId>::const_iterator const end = displayed.constEnd();
+    for (; pos != end; ++pos ) {
+        TileId const & id = *pos;
+        QUrl sourceUrl = TileLoaderHelper::downloadUrl( texture, id.zoomLevel(), id.x(), id.y() );
+        QString destFileName = TileLoaderHelper::relativeTileFileName( texture, id.zoomLevel(),
+                                                                       id.x(), id.y() );
+        emit downloadTile( sourceUrl, destFileName, id.toString() );
+    }
+}
+
 }
 
 #include "MarbleModel.moc"
