@@ -5,8 +5,8 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2008 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2008 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 
@@ -21,25 +21,24 @@
  * @author Inge Wallin  <inge@lysator.liu.se>
  */
 
-
+#include <QtGui/QActionGroup>
 #include <QtCore/QTimer>
 #include <QtGui/QWidget>
 #include <QtGui/QImage>
 #include <QtGui/QPixmap>
 #include <QtDesigner/QDesignerExportWidget>
 
-//#include <QtDBus/QtDBus>
-
 #include "marble_export.h"
 #include "GeoDataCoordinates.h"       // In geodata/data/
 #include "MarbleWidgetInputHandler.h"
+#include "Quaternion.h"
 #include "global.h"             // types needed in all of marble.
 
 // Qt
 class QAbstractItemModel;
 class QModelIndex;
 class QItemSelectionModel;
-class QStyleOptionGraphicsItem;
+class QSettings;
 
 namespace Marble
 {
@@ -49,17 +48,16 @@ namespace Marble
 class MarbleWidgetPrivate;
 
 // Marble
-class BoundingBox;
 class MarbleMap;
 class MarbleModel;
-class HttpDownloadManager;
 class TileCreator;
 class SunLocator;
 class GpxFileModel;
 class FileViewModel;
+class GeoDataLatLonBox;
 class GeoPainter;
-class MarbleRenderPlugin;
-class MarbleAbstractFloatItem;
+class RenderPlugin;
+class AbstractFloatItem;
 class GeoSceneDocument;
 
 /**
@@ -115,7 +113,9 @@ class GeoSceneDocument;
 class MARBLE_EXPORT MarbleWidget : public QWidget
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.kde.marble")
+#ifdef MARBLE_DBUS
+    Q_CLASSINFO("D-Bus Interface", "org.kde.MarbleWidget")
+#endif
 
     Q_PROPERTY(int zoom          READ zoom            WRITE zoomView)
 
@@ -185,29 +185,25 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      */
     MarbleModel  *model() const;
 
+    /**
+     * Returns the current input handler
+     */
+    MarbleWidgetInputHandler *inputHandler() const;
+
     /**
      * @brief Set the input handler
      */
     void setInputHandler(MarbleWidgetInputHandler *handler);
 
-    /**
-     * @brief Set the download manager to load missing tiles
-     * @param manager the manager instance
-     *
-     * The instance will be destructed by MarbleWidget when not
-     * used any longer.
-     */
-    void setDownloadManager( HttpDownloadManager *downloadManager );
-
     /**
      * @brief Return the active region in which it's possible to drag the view using the mouse.
      */
     const QRegion  activeRegion();
 
     /**
-     * @brief Return the active region in which it's possible to drag the view using the mouse.
+     * @brief Return the projected region which describes the (shape of the) projected surface.
      */
-    const QRegion  projectedRegion();
+    const QRegion  mapRegion();
 
     /**
      * @brief  Return the radius of the globe in pixels.
@@ -221,7 +217,7 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     void        setRadius(int radius);
 
     /**
-     * @brief Return the current zoom level.
+     * @brief Return the current zoom amount.
      */
     int         zoom() const;
 
@@ -270,7 +266,7 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      *         @c false if the geographical coordinates are not visible on the screen
      */
     bool screenCoordinates( qreal lon, qreal lat,
-                            int& x, int& y );
+                            qreal& x, qreal& y );
 
     /**
      * @brief Get the Y coordinate of the North Pole.
@@ -291,18 +287,6 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
                          qreal& lon, qreal& lat,
                          GeoDataCoordinates::Unit = GeoDataCoordinates::Degree );
 
-    /**
-     * @brief Get a quaternion representing a point on the earth corresponding to a pixel in the widget.
-     * @param x  the x coordinate of the pixel
-     * @param y  the y coordinate of the pixel
-     * @param q  the out parameter where the result is returned
-     * @return @c true  if the pixel (x, y) is within the globe
-     *         @c false if the pixel (x, y) is outside the globe, i.e. in space
-     */
-    bool    globalQuaternion( int x, int y, Quaternion &q);
-    // FIXME: Make the names of globalQuaternion() and
-    //        geoCoordinates() follow a pattern.
-
     /**
      * @brief Return the longitude of the center point.
      */
@@ -316,12 +300,12 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     /**
      * @brief Returns the model for all the placemarks on the globe.
      */
-    QAbstractItemModel *placeMarkModel() const;
+    QAbstractItemModel *placemarkModel() const;
 
     /**
      * @brief Returns the selection model for all the placemarks on the globe.
      */
-    QItemSelectionModel *placeMarkSelectionModel() const;
+    QItemSelectionModel *placemarkSelectionModel() const;
 
     /**
      * @brief  Return how much the map will move if one of the move slots are called.
@@ -331,22 +315,22 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
 
     /**
      * @brief  Add a GeoDataPlacemark file to the model.
-     * @param  filename  the filename of the file containing the PlaceMarks.
+     * @param  filename  the filename of the file containing the Placemarks.
      */
-    void addPlaceMarkFile( const QString &filename );
+    void addPlacemarkFile( const QString &filename );
 
     /**
      * @brief  Add GeoDataPlacemark data as string to the model.
-     * @param  data  the string containing the PlaceMarks.
+     * @param  data  the string containing the Placemarks.
      * @param key  the string needed to identify the data
      */
-    void addPlaceMarkData( const QString& data, const QString& key = "data" );
+    void addPlacemarkData( const QString& data, const QString& key = "data" );
     
     /**
      * @brief  remove data or files from the model.
-     * @param key  either the filename or the string used to identify the data in addPlaceMarkFile and addPlaceMarkData
+     * @param key  either the filename or the string used to identify the data in addPlacemarkFile and addPlacemarkData
      */
-    void removePlaceMarkKey( const QString& key );
+    void removePlacemarkKey( const QString& key );
 
     /**
      * @brief  Return the quaternion that specifies the rotation of the globe.
@@ -487,13 +471,40 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
 
     SunLocator* sunLocator();
 
-    void setProxy( const QString& proxyHost, const quint16 proxyPort );
+    //These methods should all be removed
+    // what does this do to binary compatibility?
+    void setProxy( const QString& proxyHost, const quint16 proxyPort, const QString& user, const QString& password );
     QString proxyHost() const;
     quint16 proxyPort() const;
+    QString user() const;
+    QString password() const;
 
-    QList<MarbleRenderPlugin *>      renderPlugins() const;
-    QList<MarbleAbstractFloatItem *> floatItems()    const;
+    /**
+     * @brief Returns a list of all RenderPlugins on the widget, this includes float items
+     * @return the list of RenderPlugins
+     */
+    QList<RenderPlugin *>      renderPlugins() const;
+    /**
+     * @brief Returns a list of all FloatItems on the widget
+     * @return the list of the floatItems
+     */
+    QList<AbstractFloatItem *> floatItems()    const;
 
+    /**
+     * Reads the plugin settings from the passed QSettings.
+     * You shouldn't use this in a KDE application as these use KConfig. Here you could
+     * use MarblePart which is handling this automatically.
+     * @param settings The QSettings object to be used.
+     */
+    void readPluginSettings( QSettings& settings );
+
+    /**
+     * Writes the plugin settings in the passed QSettings.
+     * You shouldn't use this in a KDE application as these use KConfig. Here you could
+     * use MarblePart which is handling this automatically.
+     * @param settings The QSettings object to be used.
+     */
+    void writePluginSettings( QSettings& settings ) const;
 
     /**
      * @brief  Get the Projection used for the map
@@ -518,17 +529,17 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     /**
      * @brief Get the GeoSceneDocument object of the current map theme
      */
-    Marble::GeoSceneDocument *mapTheme() const;
+    Marble::GeoSceneDocument * mapTheme() const;
 
     /**
      * @brief Return a QAbstractItemModel containing GPX files.
      */
-    GpxFileModel  *gpxFileModel();
+    GpxFileModel * gpxFileModel();
 
     /**
      * @brief Return a QAbstractItemModel containing files.
      */
-    FileViewModel* fileViewModel() const;
+    FileViewModel * fileViewModel() const;
 
     /**
      * @brief Retrieve the map quality depending on the view context 
@@ -555,8 +566,7 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
 
     void updateSun();
     void centerSun();
-    void enableInput();
-    void disableInput();
+    void setInputEnabled( bool );
 //    void repaintMap();
     
     /**
@@ -605,9 +615,9 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
 
     /**
      * @brief  Center the view on a geographical point
-     * @param  lat  an angle parallel to the latitude lines
+     * @param  lat  an angle in degrees parallel to the latitude lines
      *              +90(N) - -90(S)
-     * @param  lon  an angle parallel to the longitude lines
+     * @param  lon  an angle in degrees parallel to the longitude lines
      *              +180(W) - -180(E)
      */
     void  centerOn( const qreal &lon, const qreal &lat, bool animated = false );
@@ -620,11 +630,25 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
 
     /**
      * @brief  Center the view on a point
-     * @param  point the point above earth from which the view can be seen
-     *               by looking vertically down.
+     * This method centers the Marble map on the point described by the latitude
+     * and longitude in the GeoDataCoordinate parameter @c point. It also zooms
+     * the map to be at the elevation described by the altitude. If this is
+     * not the desired functionality or you do not have an accurate altitude
+     * then use @see centerOn(qreal, qreal, bool)
+     * @param point the point in 3 dimensions above the globe to move the view
+     *              to. It will always be looking vertically down.
      */
     void  centerOn( const GeoDataCoordinates &point, bool animated = false );
 
+    /**
+     * @brief Center the view on a bounding box so that it completely fills the viewport
+     * This method not only centers on the center of the GeoDataLatLon box but it also
+     * adjusts the zoom of the marble widget so that the LatLon box provided fills
+     * the viewport.
+     * @param box The GeoDataLatLonBox to zoom and move the MarbleWidget to.
+     */
+    void centerOn( const GeoDataLatLonBox& box, bool animated = false );
+
     /**
      * @brief  Set the latitude for the center point
      * @param  lat  the new value for the latitude
@@ -821,11 +845,20 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      */
     void setShowFrameRate( bool visible );
 
+    /**
+     * @brief Set whether the is tile is visible
+     * NOTE: This is part of the transitional debug API
+     *       and might be subject to changes until Marble 0.8
+     * @param visible visibility of the tile
+     */
+    void setShowTileId( bool visible);
+
     /**
      * @brief Set the current Gps position
      * @param lat the new latitude value
      * @param lon the new longitude value
      */
+    
     void changeCurrentPosition( qreal lon, qreal lat );
 
      /**
@@ -846,7 +879,7 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     void clearPersistentTileCache();
     /**
      * @brief  Set the limit of the persistent (on hard disc) tile cache.
-     * @param  kilobytes The limit in kilobytes.
+     * @param  kilobytes The limit in kilobytes, 0 means no limit.
      */
     void setPersistentTileCacheLimit( quint64 kiloBytes );
 
@@ -883,21 +916,9 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     void updateChangedMap();
 
     /**
-     * @brief Update part of the map as defined in the BoundingBox
+     * Schedule repaint
      */
-    void updateRegion( BoundingBox& );
-
-    /**
-     * @brief Set the download url to load missing tiles
-     * @param url the url string
-     */
-    void setDownloadUrl( const QString &url );
-
-    /**
-     * @brief Set the download url to load missing tiles
-     * @param url the url objects
-     */
-    void setDownloadUrl( const QUrl &url );
+    void scheduleRepaint( QRegion dirtyRegion );
 
     /**
      * @brief Set the map quality depending on the view context 
@@ -951,6 +972,16 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      */
     void  regionSelected(const QList<double>&);
 
+    /**
+     * This signal is emit when the settings of a plugin changed.
+     */
+    void pluginSettingsChanged();
+    
+    /**
+     * @brief Signal that a render item has been initialized
+     */
+    void renderPluginInitialized( RenderPlugin *renderPlugin );
+
  protected:
     /**
      * @brief Reimplementation of the leaveEvent() function in QWidget.
@@ -977,11 +1008,15 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     void  connectNotify ( const char * signal );
     void  disconnectNotify ( const char * signal );
 
+    /**
+      * @brief Reimplementation of the changeEvent() function in QWidget to
+      * react to changes of the enabled state
+      */
+    void changeEvent ( QEvent * event );
+
  private:
     Q_DISABLE_COPY( MarbleWidget )
     MarbleWidgetPrivate  * const d;
-
-    Q_PRIVATE_SLOT( d, void _q_initGui() )
 };
 
 }
