@@ -36,8 +36,7 @@ namespace Marble
 class GeoScenePalette : public GeoNode
 {
  public:
-    explicit GeoScenePalette( const QString& type, const QString& file );
-    ~GeoScenePalette();
+    GeoScenePalette( const QString& type, const QString& file );
 
     QString type() const;
     void    setType( const QString& type );
@@ -45,7 +44,7 @@ class GeoScenePalette : public GeoNode
     QString file() const;
     void    setFile( const QString& file );
 
-    bool operator==( const GeoScenePalette& other );
+    bool operator==( const GeoScenePalette& rhs ) const;
 
  private:
     QString m_type;
